@@ -61,6 +61,7 @@ class encryptContentPlugin(BasePlugin):
         # password feature
         ('global_password', config_options.Type(string_types, default=None)),
         ('use_secret', config_options.Type(string_types, default=None)),
+        ('ignore_missing_secret', config_options.Type(bool, default=False)),
         ('password', config_options.Type(string_types, default=None)),
         ('remember_password', config_options.Type(bool, default=False)),
         ('session_storage', config_options.Type(bool, default=True)),
@@ -189,12 +190,16 @@ class encryptContentPlugin(BasePlugin):
             if os.environ.get(str(self.config['use_secret'])):
                 self.config['global_password'] = os.environ.get(str(self.config['use_secret']))
             else:
-                logger.error('Cannot get global password from environment variable: {var}. Abort !'.format(
-                    var=str(self.config['use_secret']))
-                )
-                os._exit(1)                                 # prevent build without password to avoid leak
-        # Set global password as default password for each page
-        self.config['password'] = self.config['global_password']
+                if self.config['ignore_missing_secret'] and self.config['global_password']:
+                    logger.warning('Cannot get global password from environment variable: {var}. Using global_password as fallback!'.format(
+                        var=str(self.config['use_secret']))
+                    )
+                else:
+                    logger.error('Cannot get global password from environment variable: {var}. Abort !'.format(
+                        var=str(self.config['use_secret']))
+                    )
+                    os._exit(1)                                 # prevent build without password to avoid leak
+
         # Check if hljs feature need to be enabled, based on theme configuration
         if ('highlightjs' in config['theme']._vars
                 and config['theme']._vars['highlightjs']    # noqa: W503
@@ -281,7 +286,7 @@ class encryptContentPlugin(BasePlugin):
         The page_markdown event is called after the page's markdown is loaded from file and
         can be used to alter the Markdown source text. The meta- data has been stripped off
         and is available as page.meta at this point.
-        Load password from meta header *.md pages and override global_password if define.
+        Load password from meta header *.md pages and override global_password if defined.
 
         :param markdown: Markdown source text of page as string
         :param page: mkdocs.nav.Page instance
@@ -289,13 +294,31 @@ class encryptContentPlugin(BasePlugin):
         :param site_navigation: global navigation object
         :return: Markdown source text of page as string
         """
+
+        # Set global password as default password for each page
         self.config['password'] = self.config['global_password']
+
         if 'password' in page.meta.keys():
             # If global_password is set, but you don't want to encrypt content
             page_password = str(page.meta.get('password'))
             self.config['password'] = None if page_password == '' else page_password
             # Delete meta password information before rendering to avoid leak :]
             del page.meta['password']
+
+        if 'use_secret' in page.meta.keys():
+            if os.environ.get(str(page.meta.get('use_secret'))):
+                self.config['password'] = os.environ.get(str(page.meta.get('use_secret')))
+            else:
+                if self.config['ignore_missing_secret'] and self.config['password']:
+                    logger.warning('Cannot get password for "{page}" from environment variable: {var}. Using password from config or meta key as fallback!'.format(
+                        var=str(page.meta.get('use_secret')), page=page.title)
+                    )
+                else:
+                    logger.error('Cannot get password for "{page}" from environment variable: {var}. Abort !'.format(
+                        var=str(page.meta.get('use_secret')), page=page.title)
+                    )
+                    os._exit(1)                                 # prevent build without password to avoid leak0
+
         return markdown
 
     def on_page_content(self, html, page, config, **kwargs):
@@ -427,6 +450,7 @@ class encryptContentPlugin(BasePlugin):
                 delattr(page, 'decrypt_form')
             output_content = str(soup)
 
+        #TODO: Move search index processing to on_post_build to be less likely to fail due to incompatible search plugins
         if hasattr(page, 'encrypted'):
             #encrypt or exclude encrypted pages from search_index.json
             for plugin in config['plugins']:
@@ -462,8 +486,8 @@ class encryptContentPlugin(BasePlugin):
                             config['plugins'][plugin].search_index.entries = search_entries
 
                     except:
-                        logger.error('Could not encrypt search index of "' + page.title + '" for "' + plugin+ '" plugin!')
-
+                        logger.error('Could not encrypt search index of "' + page.title + '" for "' + plugin+ '" plugin! Abort !')
+                        os._exit(1)                                 # prevent build with possible plaintext in search_index
         return output_content
 
     def on_post_build(self, config, **kwargs):
